/*
 *    GS2MGRetrieve.java
 *    Copyright (C) 2005 New Zealand Digital Library, http://www.nzdl.org
 *
 *    This program is free software; you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation; either version 2 of the License, or
 *    (at your option) any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program; if not, write to the Free Software
 *    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
package org.greenstone.gsdl3.service;

// Greenstone classes
import org.greenstone.mg.*;
import org.greenstone.gsdl3.core.GSException;
import org.greenstone.gsdl3.util.GSFile;
import org.greenstone.gsdl3.util.GSXML;

// XML classes
import org.w3c.dom.Element;
import org.w3c.dom.Text;

// General Java classes
import java.io.File;

public class GS2MGRetrieve
    extends AbstractGS2DocumentRetrieve
{
    // Elements used in the config file that are specific to this class
    private static final String DEFAULT_INDEX_ELEM = "defaultIndex";

    private MGWrapper mg_src = null;
    private String mg_basedir = null;
    private String mg_textdir = null;
    private String default_index = null;
	
    public GS2MGRetrieve() {
	this.mg_src = new MGWrapper();
    }

    /** configure this service */
    public boolean configure(Element info, Element extra_info)
    {
	// Do specific configuration
	System.out.println("Configuring GS2MGRetrieve...");
	// System.out.println("info:\n" + converter_.getString(info));
	// System.out.println("extra_info:\n" + converter_.getString(extra_info));

	// Get the default index out of <defaultIndex> (buildConfig.xml)
	Element def = (Element) GSXML.getChildByTagName(info, DEFAULT_INDEX_ELEM);
	if (def != null) {
	    this.default_index = def.getAttribute(GSXML.NAME_ATT);
	}
	if (this.default_index == null || this.default_index.equals("")) {
	    System.err.println("Error: default index not specified!");
	    return false;
	}
	// System.out.println("Default index: " + this.default_index);

	// The location of the MG index and text files
	mg_basedir = GSFile.collectionBaseDir(this.site_home, this.cluster_name) + File.separatorChar;  // Needed by MG
	mg_textdir = GSFile.collectionTextPath(this.cluster_name);
	// index is only needed to start up MG, not used so just use the default index
	String indexpath = GSFile.collectionIndexPath(this.cluster_name, this.default_index);
	this.mg_src.setIndex(indexpath);

	// Do generic configuration
	return super.configure(info, extra_info);
    }
    
    /** returns the content of a node
     * should return a nodeContent element:
     * <nodeContent>text content or other elements</nodeContent>
     */
    protected Element getNodeContent(String doc_id) throws GSException {
	String lang = "en"; //  ********** 
	long doc_num = this.gdbm_src.OID2Docnum(doc_id);
	if (doc_num == -1) {
	    System.err.println("OID "+doc_id +" couldn't be converted to mg num");
	    return null;
	}
	Element content_node = this.doc.createElement(GSXML.NODE_CONTENT_ELEM);
	
	String doc_content = this.mg_src.getDocument(this.mg_basedir,
						     this.mg_textdir, doc_num);
	
	if (doc_content!=null) {
	    // remove any ctrl-c or ctrl-b 
	    doc_content = doc_content.replaceAll("\u0002|\u0003", "");
	    // replace _httpimg_ with the correct address
	    doc_content = resolveTextMacros(doc_content, doc_id, lang);
	    //GSXML.addDocText(this.doc, doc, doc_content);
	} else {
	    System.err.println("the doc content was null, not getting that section\n");
	    doc_content = "couldn't retrieve content for this section\n";
	}
	Text t = this.doc.createTextNode(doc_content);
	content_node.appendChild(t);
	return content_node;

    }


}
